.. _apidocs:

Module Documentation
====================

This page contains documentation to everything ``symfit`` has to offer.

Fit
---

.. automodule:: symfit.core.fit
   :members:
   :special-members:
   :exclude-members: __weakref__
   :show-inheritance:

Argument
--------

.. automodule:: symfit.core.argument
   :members:
   :special-members:
   :exclude-members: __weakref__
   :show-inheritance:

Operators
---------

.. automodule:: symfit.core.operators
   :members:
   :special-members:
   :exclude-members: __weakref__
   :show-inheritance:

Fit Results
-----------

.. automodule:: symfit.core.fit_results
   :members:
   :special-members:
   :exclude-members: __weakref__
   :show-inheritance:

Minimizers
----------

.. automodule:: symfit.core.minimizers
   :members:
   :special-members:
   :exclude-members: __weakref__
   :show-inheritance:

Objectives
----------

.. automodule:: symfit.core.objectives
   :members:
   :special-members:
   :exclude-members: __weakref__
   :show-inheritance:

Support
-------

.. automodule:: symfit.core.support
   :members:
   :special-members:
   :exclude-members: __weakref__
   :show-inheritance:

Distributions
-------------

.. automodule:: symfit.distributions
   :members:
   :special-members:
   :exclude-members: __weakref__
   :show-inheritance:


Contrib
-------
Contrib modules are modules and extensions to symfit provided by other people.
This usually means the code is of slightly less quality, and may not survive
future versions.

.. automodule:: symfit.contrib.interactive_guess.interactive_guess
   :members:
   :special-members:
   :exclude-members: __weakref__
   :show-inheritance:

